This function takes a matrix (m), a lambda value (lambda), the number
of desired eigenvectors (k), and a mu value (mu) as input. It then computes
eigenvectors 1 to k, penalized by the supplied lambda and smoothed by the
Nesterov smoothing function.
Usage
smoothed_penalized_EV(m, lambda, k, mu)
Value
Returns smoothed eigenvectors 1 to k for the specified lambda value.
Arguments
m
A matrix generated from a large dataset.
lambda
A numeric vector of lambda values to use for the penalty.
k
The number of eigenvectors we consider in the analysis.
mu
A number assigned to mu; we are typically using 0.1.
# Generate a small matrix for testingm <- matrix(rnorm(100), nrow = 10)
# Call function (using matrix, lambda, mu, and k)smoothed_penalized_EV(
m = m,
lambda = 1,
k = 2,
mu = 0.1)